@@ -19,7 +19,7 @@ try:
 except ModuleNotFoundError:
     pass
 
-__version__ = '0.1.7'
+__version__ = '0.1.8'
 __release__ = 20230221
 
 
@@ -50,7 +50,10 @@ def dlis2frame(path: str, use_simpandas=False, raise_error=True, correct_units=T
     l_count = -1
     for logical_file in physical_file:
         l_count += 1
-        meta = pd.DataFrame(index=range(len(logical_file.parameters)))
+        try:  # to skip RuntimeError raised by dlisio
+            meta = pd.DataFrame(index=range(len(logical_file.parameters)))
+        except:
+            meta = pd.DataFrame()
         well_name = None
         for p in range(len(logical_file.parameters)):
             meta.loc[p, 'name'] = logical_file.parameters[p].name
